use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
Florian
Ragwitz
rafl
Karen
Etheridge
ether
Graham
Knop
haarg
Dave
Rolsky
autarch
Kent
Fredric
kentfredric
Tomas
Doran
bobtfish
Shawn
Moore
sartak
Felix
Ostmann
sadrak
Chris
Prather
cprather
Andrew
Rodland
andrew
lib
namespace
autoclean
